@@ -757,6 +757,18 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
 
             daily_df['year'] = daily_df.index.year
             daily_df['month'] = daily_df.index.month
+            def get_month_date(row):
+                return datetime(year=row['year'], month=row['month'])
+
+            daily_df['month_date'] = daily_df.apply(get_month_date, axis = 1)
+
+            epochkpis_series = daily_df[['month_date', me_strat]].groupby(['month_date']).apply(go_comp_kpi)
+            epochkpis_df = pd.DataFrame().from_records(epochkpis_series.values)
+            epochkpis_df.index = epochkpis_series.index
+            epochkpis_df = epochkpis_df.sort_index()
+            epochkpis_df['year'] = epochkpis_df.index.year
+            epochkpis_df['month'] = epochkpis_df.index.month
+
 
             def rename_month(row):
                 if row['month'] == 1:
@@ -784,11 +796,14 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 if row['month'] == 12:
                     return 'December'
 
-            daily_df['month'] = daily_df.apply(rename_month, axis=1)
+            epochkpis_df['month'] = epochkpis_df.apply(rename_month, axis=1)
+            epochkpis_df = epochkpis_df.set_index(['year','month'])
 
-            epochkpis_series = daily_df[['year', 'month', me_strat]].groupby(['year', 'month']).apply(go_comp_kpi)
-            epochkpis_df = pd.DataFrame().from_records(epochkpis_series.values)
-            epochkpis_df.index = epochkpis_series.index
+            #daily_df['month'] = daily_df.apply(rename_month, axis=1)
+
+            # epochkpis_series = daily_df[['year', 'month', me_strat]].groupby(['year', 'month']).apply(go_comp_kpi)
+            # epochkpis_df = pd.DataFrame().from_records(epochkpis_series.values)
+            # epochkpis_df.index = epochkpis_series.index
             epochkpis_df = epochkpis_df.rename(columns={
                 'simple_return': 'epoch realized return',
                 'annual_return': 'epoch realized annualized return',
